@@ -1,12 +1,14 @@
 package Dist::Zilla::MVP::Assembler;
-BEGIN {
-  $Dist::Zilla::MVP::Assembler::VERSION = '4.200009';
+{
+  $Dist::Zilla::MVP::Assembler::VERSION = '4.300003';
 }
 use Moose;
 extends 'Config::MVP::Assembler';
 with 'Config::MVP::Assembler::WithBundles';
 # ABSTRACT: Dist::Zilla-specific subclass of Config::MVP::Assembler
 
+use namespace::autoclean;
+
 use Dist::Zilla::Util;
 
 
@@ -48,7 +50,7 @@ before add_value => sub {
   );
 };
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -60,7 +62,7 @@ Dist::Zilla::MVP::Assembler - Dist::Zilla-specific subclass of Config::MVP::Asse
 
 =head1 VERSION
 
-version 4.200009
+version 4.300003
 
 =head1 DESCRIPTION
 
