@@ -1,9 +1,13 @@
 package Dist::Zilla::Plugin::BumpVersion;
-our $VERSION = '1.100160';
-# ABSTRACT: bump the configured version number by one before building
+{
+  $Dist::Zilla::Plugin::BumpVersion::VERSION = '4.300003';
+}
+# ABSTRACT: (DEPRECATED) bump the version number by one before building
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild';
 
+use namespace::autoclean;
+
 
 sub before_build {
   my ($self) = @_;
@@ -25,8 +29,15 @@ sub before_build {
   $self->zilla->version("$version");
 }
 
+before register_component => sub {
+  die "Dist::Zilla::Plugin::BumpVersion is incompatible with Dist::Zilla >=
+  v5\n"
+    if Dist::Zilla->VERSION >= 5;
+
+  warn "!!! $_[0] will be removed in Dist::Zilla v5; remove it from your config\n";
+};
+
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -34,14 +45,17 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::BumpVersion - bump the configured version number by one before building
+Dist::Zilla::Plugin::BumpVersion - (DEPRECATED) bump the version number by one before building
 
 =head1 VERSION
 
-version 1.100160
+version 4.300003
 
 =head1 SYNOPSIS
 
+B<WARNING>  This plugin is deprecated and will be removed.  It is generally
+useless.  It does not do what you think it does.
+
 If loaded, this plugin will ensure that the distribution's version number is
 bumped up by one (in the smallest already-defined version units) before
 building begins.  In other words, if F<dist.ini>'s version reads C<0.002> then
@@ -49,11 +63,11 @@ the newly built dist will be C<0.003>.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
