@@ -1,14 +1,15 @@
 package Dist::Zilla::Plugin::FinderCode;
-BEGIN {
-  $Dist::Zilla::Plugin::FinderCode::VERSION = '4.101612';
+{
+  $Dist::Zilla::Plugin::FinderCode::VERSION = '4.300003';
 }
 use Moose;
 with 'Dist::Zilla::Role::FileFinder';
 # ABSTRACT: a callback-based FileFinder plugin
 
+use namespace::autoclean;
+
 use Moose::Autobox;
 use Moose::Util::TypeConstraints;
-use namespace::autoclean;
 
 has code => (
   is  => 'ro',
@@ -33,7 +34,8 @@ sub find_files {
 sub _find_via_grep {
   my ($self) = @_;
 
-  $self->zilla->files->grep($self->code);
+  my @files = grep { $self->code->($_, $self) } $self->zilla->files->flatten;
+  return \@files;
 }
 
 sub _find_via_list {
@@ -43,6 +45,7 @@ sub _find_via_list {
   $self->$code;
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -54,15 +57,15 @@ Dist::Zilla::Plugin::FinderCode - a callback-based FileFinder plugin
 
 =head1 VERSION
 
-version 4.101612
+version 4.300003
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
