@@ -1,11 +1,13 @@
 package Dist::Zilla::Plugin::License;
-BEGIN {
-  $Dist::Zilla::Plugin::License::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::License::VERSION = '4.300003';
 }
 # ABSTRACT: output a LICENSE file
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
+use namespace::autoclean;
+
 
 use Dist::Zilla::File::InMemory;
 
@@ -22,7 +24,6 @@ sub gather_files {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -34,7 +35,7 @@ Dist::Zilla::Plugin::License - output a LICENSE file
 
 =head1 VERSION
 
-version 4.200000
+version 4.300003
 
 =head1 DESCRIPTION
 
@@ -48,7 +49,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
