@@ -1,12 +1,14 @@
 package Dist::Zilla::Plugin::Manifest;
-BEGIN {
-  $Dist::Zilla::Plugin::Manifest::VERSION = '4.101900';
+{
+  $Dist::Zilla::Plugin::Manifest::VERSION = '4.300003';
 }
 # ABSTRACT: build a MANIFEST file
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
+use namespace::autoclean;
+
 use Dist::Zilla::File::FromCode;
 
 
@@ -36,7 +38,6 @@ sub gather_files {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -48,7 +49,7 @@ Dist::Zilla::Plugin::Manifest - build a MANIFEST file
 
 =head1 VERSION
 
-version 4.101900
+version 4.300003
 
 =head1 DESCRIPTION
 
@@ -62,7 +63,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
