@@ -1,14 +1,15 @@
 package Dist::Zilla::Plugin::MetaTests;
-BEGIN {
-  $Dist::Zilla::Plugin::MetaTests::VERSION = '4.101900';
+{
+  $Dist::Zilla::Plugin::MetaTests::VERSION = '4.300003';
 }
 # ABSTRACT: common extra tests for META.yml
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
 
+use namespace::autoclean;
+
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 
@@ -21,7 +22,7 @@ Dist::Zilla::Plugin::MetaTests - common extra tests for META.yml
 
 =head1 VERSION
 
-version 4.101900
+version 4.300003
 
 =head1 DESCRIPTION
 
@@ -36,7 +37,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
