@@ -1,13 +1,17 @@
 package Dist::Zilla::Plugin::NextRelease;
-BEGIN {
-  $Dist::Zilla::Plugin::NextRelease::VERSION = '4.101900';
+{
+  $Dist::Zilla::Plugin::NextRelease::VERSION = '4.300003';
 }
 # ABSTRACT: update the next release number in your changelog
 
+use namespace::autoclean;
+
 use Moose;
-with 'Dist::Zilla::Role::FileMunger';
-with 'Dist::Zilla::Role::TextTemplate';
-with 'Dist::Zilla::Role::AfterRelease';
+with (
+  'Dist::Zilla::Role::FileMunger',
+  'Dist::Zilla::Role::TextTemplate',
+  'Dist::Zilla::Role::AfterRelease',
+);
 
 use DateTime 0.44; # CLDR fixes
 use String::Formatter 0.100680 stringf => {
@@ -112,7 +116,6 @@ sub after_release {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 
@@ -124,7 +127,7 @@ Dist::Zilla::Plugin::NextRelease - update the next release number in your change
 
 =head1 VERSION
 
-version 4.101900
+version 4.300003
 
 =head1 SYNOPSIS
 
@@ -214,7 +217,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
