@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PkgVersion;
-BEGIN {
-  $Dist::Zilla::Plugin::PkgVersion::VERSION = '4.200009';
+{
+  $Dist::Zilla::Plugin::PkgVersion::VERSION = '4.300003';
 }
 # ABSTRACT: add a $VERSION to your packages
 use Moose;
@@ -9,6 +9,7 @@ with(
   'Dist::Zilla::Role::FileFinderUser' => {
     default_finders => [ ':InstallModules', ':ExecFiles' ],
   },
+  'Dist::Zilla::Role::PPI',
 );
 
 use PPI;
@@ -43,21 +44,11 @@ sub munge_perl {
   Carp::croak("invalid characters in version")
     unless LaxVersionStr->check($version);
 
-  my $content = $file->content;
+  my $document = $self->ppi_document_for_file($file);
 
-  my $document = PPI::Document->new(\$content)
-    or Carp::croak( PPI::Document->errstr );
-
-  {
-    # This is sort of stupid.  We want to see if we assign to $VERSION already.
-    # I'm sure there's got to be a better way to do this, but what the heck --
-    # this should work and isn't too slow for me. -- rjbs, 2009-11-29
-    my $code_only = $document->clone;
-    $code_only->prune("PPI::Token::$_") for qw(Comment Pod Quote Regexp);
-    if ($code_only->serialize =~ /\$VERSION\s*=/sm) {
-      $self->log([ 'skipping %s: assigns to $VERSION', $file->name ]);
-      return;
-    }
+  if ($self->document_assigns_to_variable($document, '$VERSION')) {
+    $self->log([ 'skipping %s: assigns to $VERSION', $file->name ]);
+    return;
   }
 
   return unless my $package_stmts = $document->find('PPI::Statement::Package');
@@ -81,7 +72,7 @@ sub munge_perl {
     # an assignment to version; it shouldn't be needed, but it's been annoying
     # enough in the past that I'm keeping it here until tests are better
     my $trial = $self->zilla->is_trial ? ' # TRIAL' : '';
-    my $perl = "BEGIN {\n  \$$package\::VERSION\x20=\x20'$version';$trial\n}\n";
+    my $perl = "{\n  \$$package\::VERSION\x20=\x20'$version';$trial\n}\n";
 
     my $version_doc = PPI::Document->new(\$perl);
     my @children = $version_doc->schildren;
@@ -97,11 +88,10 @@ sub munge_perl {
       and    $stmt->insert_after( PPI::Token::Whitespace->new("\n") );
   }
 
-  $file->content($document->serialize);
+  $self->save_ppi_document_to_file($document, $file);
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -113,7 +103,7 @@ Dist::Zilla::Plugin::PkgVersion - add a $VERSION to your packages
 
 =head1 VERSION
 
-version 4.200009
+version 4.300003
 
 =head1 SYNOPSIS
 
@@ -126,7 +116,7 @@ in dist.ini
 This plugin will add lines like the following to each package in each Perl
 module or program (more or less) within the distribution:
 
-  BEGIN {
+  {
     $MyModule::VERSION = 0.001;
   }
 
