@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PruneCruft;
-BEGIN {
-  $Dist::Zilla::Plugin::PruneCruft::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::PruneCruft::VERSION = '4.300003';
 }
 # ABSTRACT: prune stuff that you probably don't mean to include
 use Moose;
@@ -8,6 +8,8 @@ use Moose::Autobox;
 use Moose::Util::TypeConstraints;
 with 'Dist::Zilla::Role::FilePruner';
 
+use namespace::autoclean;
+
 
 {
   my $type = subtype as 'ArrayRef[RegexpRef]';
@@ -65,7 +67,6 @@ sub prune_files {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -77,7 +78,7 @@ Dist::Zilla::Plugin::PruneCruft - prune stuff that you probably don't mean to in
 
 =head1 VERSION
 
-version 4.200000
+version 4.300003
 
 =head1 SYNOPSIS
 
@@ -102,7 +103,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
