@@ -1,11 +1,13 @@
 package Dist::Zilla::PluginBundle::Classic;
-BEGIN {
-  $Dist::Zilla::PluginBundle::Classic::VERSION = '4.101900';
+{
+  $Dist::Zilla::PluginBundle::Classic::VERSION = '4.300003';
 }
 # ABSTRACT: the classic (old) default configuration for Dist::Zilla
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+use namespace::autoclean;
+
 sub configure {
   my ($self) = @_;
 
@@ -33,7 +35,6 @@ sub configure {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 
@@ -45,7 +46,7 @@ Dist::Zilla::PluginBundle::Classic - the classic (old) default configuration for
 
 =head1 VERSION
 
-version 4.101900
+version 4.300003
 
 =head1 DESCRIPTION
 
@@ -136,7 +137,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
