@@ -1,15 +1,16 @@
 package Dist::Zilla::Role::AfterMint;
-BEGIN {
-  $Dist::Zilla::Role::AfterMint::VERSION = '4.200000';
+{
+  $Dist::Zilla::Role::AfterMint::VERSION = '4.300003';
 }
 # ABSTRACT: something that runs after minting is mostly complete
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'after_mint';
 
-no Moose::Role;
 1;
 
 __END__
@@ -21,7 +22,7 @@ Dist::Zilla::Role::AfterMint - something that runs after minting is mostly compl
 
 =head1 VERSION
 
-version 4.200000
+version 4.300003
 
 =head1 DESCRIPTION
 
@@ -37,7 +38,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
