@@ -1,17 +1,18 @@
 package Dist::Zilla::Role::Chrome;
-BEGIN {
-  $Dist::Zilla::Role::Chrome::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::Chrome::VERSION = '4.300003';
 }
 # ABSTRACT: something that provides a user interface for Dist::Zilla
 use Moose::Role;
 
+use namespace::autoclean;
+
 requires 'logger';
 
 requires 'prompt_str';
 requires 'prompt_yn';
 requires 'prompt_any_key';
 
-
 1;
 
 __END__
@@ -23,7 +24,7 @@ Dist::Zilla::Role::Chrome - something that provides a user interface for Dist::Z
 
 =head1 VERSION
 
-version 4.200009
+version 4.300003
 
 =head1 AUTHOR
 
