@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::Plugin;
-BEGIN {
-  $Dist::Zilla::Role::Plugin::VERSION = '4.200000';
+{
+  $Dist::Zilla::Role::Plugin::VERSION = '4.300003';
 }
 # ABSTRACT: something that gets plugged in to Dist::Zilla
 use Moose::Role;
@@ -69,7 +69,6 @@ sub register_component {
   return;
 }
 
-no Moose::Role;
 1;
 
 __END__
@@ -81,7 +80,7 @@ Dist::Zilla::Role::Plugin - something that gets plugged in to Dist::Zilla
 
 =head1 VERSION
 
-version 4.200000
+version 4.300003
 
 =head1 DESCRIPTION
 
@@ -112,7 +111,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
