@@ -1,12 +1,14 @@
 package Dist::Zilla::Role::PluginBundle::Easy;
-BEGIN {
-  $Dist::Zilla::Role::PluginBundle::Easy::VERSION = '4.101900';
+{
+  $Dist::Zilla::Role::PluginBundle::Easy::VERSION = '4.300003';
 }
 # ABSTRACT: something that bundles a bunch of plugins easily
 # This plugin was originally contributed by Christopher J. Madsen
 use Moose::Role;
 with 'Dist::Zilla::Role::PluginBundle';
 
+use namespace::autoclean;
+
 
 use Moose::Autobox;
 use MooseX::Types::Moose qw(Str ArrayRef HashRef);
@@ -140,7 +142,7 @@ Dist::Zilla::Role::PluginBundle::Easy - something that bundles a bunch of plugin
 
 =head1 VERSION
 
-version 4.101900
+version 4.300003
 
 =head1 SYNOPSIS
 
@@ -234,7 +236,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
