@@ -1,15 +1,16 @@
 package Dist::Zilla::Role::TestRunner;
-BEGIN {
-  $Dist::Zilla::Role::TestRunner::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::TestRunner::VERSION = '4.300003';
 }
 # ABSTRACT: something used as a delegating agent to 'dzil test'
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'test';
 
-no Moose::Role;
 1;
 
 __END__
@@ -21,7 +22,7 @@ Dist::Zilla::Role::TestRunner - something used as a delegating agent to 'dzil te
 
 =head1 VERSION
 
-version 4.200009
+version 4.300003
 
 =head1 DESCRIPTION
 
