@@ -1,11 +1,15 @@
 package Dist::Zilla::Tester;
-BEGIN {
-  $Dist::Zilla::Tester::VERSION = '4.101900';
+{
+  $Dist::Zilla::Tester::VERSION = '4.300003';
 }
 use Moose;
 extends 'Dist::Zilla::Dist::Builder';
 # ABSTRACT: a testing-enabling stand-in for Dist::Zilla
 
+# XXX: Adding this autoclean causes problem.  "Builder" and "Minter" do not
+# show in in tests.  I'm really not sure why. -- rjbs, 2011-08-19
+# use namespace::autoclean;
+
 use autodie;
 use Dist::Zilla::Chrome::Test;
 use File::pushd ();
@@ -33,8 +37,8 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 
 {
   package Dist::Zilla::Tester::_Role;
-BEGIN {
-  $Dist::Zilla::Tester::_Role::VERSION = '4.101900';
+{
+  $Dist::Zilla::Tester::_Role::VERSION = '4.300003';
 }
   use Moose::Role;
 
@@ -79,8 +83,8 @@ BEGIN {
 
 {
   package Dist::Zilla::Tester::_Builder;
-BEGIN {
-  $Dist::Zilla::Tester::_Builder::VERSION = '4.101900';
+{
+  $Dist::Zilla::Tester::_Builder::VERSION = '4.300003';
 }
   use Moose;
   extends 'Dist::Zilla::Dist::Builder';
@@ -175,8 +179,8 @@ BEGIN {
 
 {
   package Dist::Zilla::Tester::_Minter;
-BEGIN {
-  $Dist::Zilla::Tester::_Minter::VERSION = '4.101900';
+{
+  $Dist::Zilla::Tester::_Minter::VERSION = '4.300003';
 }
   use Moose;
   extends 'Dist::Zilla::Dist::Minter';
@@ -254,6 +258,8 @@ BEGIN {
   };
 }
 
+no Moose; # XXX: namespace::autoclean caused problems -- rjbs, 2011-08-19
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -265,7 +271,7 @@ Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 4.101900
+version 4.300003
 
 =head1 AUTHOR
 
@@ -273,7 +279,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
