@@ -1,9 +1,11 @@
 package Dist::Zilla::Types;
-BEGIN {
-  $Dist::Zilla::Types::VERSION = '4.101900';
+{
+  $Dist::Zilla::Types::VERSION = '4.300003';
 }
 # ABSTRACT: dzil-specific type library
 
+use namespace::autoclean;
+
 
 use MooseX::Types -declare => [qw(License OneZero YesNoStr)];
 use MooseX::Types::Moose qw(Str Int);
@@ -27,7 +29,7 @@ Dist::Zilla::Types - dzil-specific type library
 
 =head1 VERSION
 
-version 4.101900
+version 4.300003
 
 =head1 OVERVIEW
 
@@ -43,7 +45,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
